@@ -1,4 +1,4 @@
-#  Copyright (c) 2002-2010 Zooko Wilcox-O'Hearn
+#  Copyright (c) 2002-2012 Zooko Wilcox-O'Hearn
 #  This file is part of pyutil; see README.rst for licensing terms.
 
 """
@@ -85,7 +85,7 @@ and the main function is to make them be methods of the same object, e.g.:
  this work and send me a patch!
 """
 
-import cProfile, math, operator, sys, time
+import cProfile, operator, sys, time
 from decimal import Decimal as D
 
 #from pyutil import jsonutil as json
@@ -127,21 +127,28 @@ def rep_bench(func, n, initfunc=None, MAXREPS=10, MAXTIME=60.0, profile=False, p
     tls.sort()
     worst = tls[-1]
     best = tls[0]
-    m = min(int(math.log(len(tls)))+1, len(tls))
-    mthworst = tls[-m]
-    mthbest = tls[m-1]
+    m = len(tls)/4
+    if m > 0:
+        mthbest = tls[m-1]
+        mthworst = tls[-m]
+    else:
+        mthbest = tls[0]
+        mthworst = tls[-1]
 
+    # The +/-0 index is the best/worst, the +/-1 index is the 2nd-best/worst,
+    # etc, so we use mp1 to name it.
+    mp1 = m+1
     res = {
         'worst': worst/n,
         'best': best/n,
-        'm': m,
+        'mp1': mp1,
         'mth-best': mthbest/n,
         'mth-worst': mthworst/n,
         'mean': mean/n,
         'num': len(tls),
         }
 
-    print "best: %(best)#8.03e, %(m)3dth-best: %(mth-best)#8.03e, mean: %(mean)#8.03e, %(m)3dth-worst: %(mth-worst)#8.03e, worst: %(worst)#8.03e (of %(num)6d)" % res
+    print "best: %(best)#8.03e, %(mp1)3dth-best: %(mth-best)#8.03e, mean: %(mean)#8.03e, %(mp1)3dth-worst: %(mth-worst)#8.03e, worst: %(worst)#8.03e (of %(num)6d)" % res
 
     return res
 
